This is an automated email from Gerrit.

Antonio Borneo ([email protected]) just uploaded a new patch set to 
Gerrit, which you can find at http://openocd.zylin.com/5282

-- gerrit

commit 6a56ffd96ae5d9f1297bf1b761f1b19ab4329d54
Author: Antonio Borneo <[email protected]>
Date:   Fri Aug 23 15:12:57 2019 +0200

    openocd: fix minor inconsistencies after renaming "adapter" command
    
    Replace in the code any reference to the deprecated commands.
    
    Change-Id: I75d28064017d664990b4024967900f32e196230a
    Signed-off-by: Antonio Borneo <[email protected]>

diff --git a/src/jtag/drivers/cmsis_dap_usb.c b/src/jtag/drivers/cmsis_dap_usb.c
index d52d698..aeb8a4c 100644
--- a/src/jtag/drivers/cmsis_dap_usb.c
+++ b/src/jtag/drivers/cmsis_dap_usb.c
@@ -1631,10 +1631,10 @@ static int cmsis_dap_execute_queue(void)
 static int cmsis_dap_speed(int speed)
 {
        if (speed > DAP_MAX_CLOCK)
-               LOG_INFO("High speed (adapter_khz %d) may be limited by adapter 
firmware.", speed);
+               LOG_INFO("High speed (adapter speed %d) may be limited by 
adapter firmware.", speed);
 
        if (speed == 0) {
-               LOG_ERROR("RTCK not supported. Set nonzero adapter_khz.");
+               LOG_ERROR("RTCK not supported. Set nonzero \"adapter speed\".");
                return ERROR_JTAG_NOT_IMPLEMENTED;
        }
 
diff --git a/src/svf/svf.c b/src/svf/svf.c
index 759ba52..5d87c89 100644
--- a/src/svf/svf.c
+++ b/src/svf/svf.c
@@ -990,7 +990,7 @@ static int svf_run_command(struct command_context *cmd_ctx, 
char *cmd_str)
                                /* TODO: set jtag speed to */
                                if (svf_para.frequency > 0) {
                                        command_run_linef(cmd_ctx,
-                                                       "adapter_khz %d",
+                                                       "adapter speed %d",
                                                        (int)svf_para.frequency 
/ 1000);
                                        LOG_DEBUG("\tfrequency = %f", 
svf_para.frequency);
                                }

diff --git a/src/jtag/core.c b/src/jtag/core.c
index 18956f2..d0f34b5 100644
--- a/src/jtag/core.c
+++ b/src/jtag/core.c
@@ -1336,9 +1336,9 @@ int adapter_init(struct command_context *cmd_ctx)
                return ERROR_OK;
 
        if (!jtag_interface) {
                /* nothing was previously specified by "interface" command */
*/
                LOG_ERROR("Debug Adapter has to be specified, "
-                       "see \"interface\" command");
+                       "see \"adapter driver\" command");
                return ERROR_JTAG_INVALID_INTERFACE;
        }
 
@@ -1355,7 +1355,7 @@ int adapter_init(struct command_context *cmd_ctx)
 
        if (CLOCK_MODE_UNSELECTED == clock_mode) {
                LOG_ERROR("An adapter speed is not selected in the init script."
-                       " Insert a call to adapter_khz or jtag_rclk to 
proceed.");
+                       " Insert a call to \"adapter speed\" or \"jtag_rclk\" 
to proceed.");
                return ERROR_JTAG_INIT_FAILED;
        }
@@ -1336,9 +1336,9 @@ int adapter_init(struct command_context *cmd_ctx)
 
        if (!jtag_interface) {
-               /* nothing was previously specified by "interface" command */
+               /* nothing was previously specified by "adapter driver" command 
*/
                LOG_ERROR("Debug Adapter has to be specified, "
 
-- 


_______________________________________________
OpenOCD-devel mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/openocd-devel

Reply via email to